#' Generate Co-inertia Analysis Figure
#'
#' This function generate output plots of CIA. Functions are based on the functions included in the R package ade4 and made4.
#' @param X inputs generated by the function genpinput contains estimated loaading vectors, normalized loading vectors, 
#' labels of variables of two datasets, group labels for samples.
#' @param nlab  number of labels that is shown in the figure.
#' @return This function returns three different figures. 
#' @examples
#' library(pCIA)
#' data(list="NCI60", package="made4")
#' X <- t(NCI60$Ross)
#' Y <- t(NCI60$Affy)
#' D <- diag(dim(X)[1]); Qx <- diag(apply(abs(X), 2, sum) / sum(abs(X))); Qy <- diag(apply(abs(Y), 2, sum) / sum(abs(Y)))
#' nX <- sweep(X, 2, apply(X, 2, mean)); nY <- sweep(Y, 2, apply(Y, 2, mean))
#' result.cia <- oCIA(nX, nY, D, Qx, Qy)
#' pinput <- genpInput(result.cia, NCI60$Annot[,2], NCI60$Annot[,4], NCI60$classes[,1], NCI60$classes[,2], nX, nY, D, Qx, Qy)
#' plot(pinput, nlab=5, labels = NULL)

#' @export
plot.pcia = function(x, nlab = 10, labels=NULL,...){
  if (!inherits(x, "pcia")) 
    stop("Object of class pcia is expected")
  if (!is.null(x$namesX)){
    genelabels1 = x$namesX
  }else{
    genelabels1 = seq(1, dim(x$co)[1])
  }
  if (!is.null(x$namesY)){
    genelabels2 = x$namesY
  }else{
    genelabels2 = seq(1, dim(x$li)[1])
  }
  classvec=x$class
  layout(matrix(c(1, 1, 2, 3), 2, 2, byrow = TRUE))
  if (!is.null(classvec)) {
    classvec <- as.factor(classvec)
    cols <- as.numeric(classvec)
  }else{
    cols <- rep(1, dim(x$mX)[1])
  }
  if (!is.null(labels)){
    label <- row.names(x$mX)
  }else{
    label <- rep("", dim(x$mX)[1])
  }
  pCIA:::s.match.col(x$mX, x$mY, xax = 1, yax = 2, label = label, classvec = unique(x$class),
              sub = paste(x$call[1], " of data ", x$call[2], " and data ", x$call[3], sep = ""),
              col = cols)
  pCIA:::plotgenes(x$co, genelabels = genelabels1, nlab = nlab, axis1 = 1, axis2 = 2, 
            sub = paste("variables data ", x$call[2], sep = ""))
  pCIA:::plotgenes(x$li, genelabels = genelabels2, nlab = nlab, axis1 = 1, axis2 = 2, 
            sub = paste("variables data ", x$call[3], sep = ""))
}
