## ----setup, include = FALSE----------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ------------------------------------------------------------------------
library(pCIA)
data("demoData")
attach(demoData)
X <- setX[1:n,]; nX <- sweep(X, 2, apply(X, 2, mean))
Y <- setY[1:n,]; nY <- sweep(Y, 2, apply(Y, 2, mean))

## ------------------------------------------------------------------------
result.cia <- oCIA(nX, nY, D, Qx, Qy) # this conduct classic CIA

## ----fig.width=10, fig.height=4------------------------------------------
par(mfrow=c(1,2))
plot(ta[,1], xlab="index", ylab="a", pch=1, cex=0.7)
points(result.cia$res.opta[,1], pch=2, cex=0.3, col="red")
plot(tb[,1], xlab="index", ylab="b", pch=1, cex=0.7)
points(result.cia$res.optb[,1], pch=2, cex=0.3, col="red")

## ------------------------------------------------------------------------
result.scia <- fitscia(nX, nY, result.cia$res.opta[,1], result.cia$res.optb[,1], c(6, 6))

## ----fig.width=10, fig.height=4------------------------------------------
par(mfrow=c(1,2))
plot(ta[,1], xlab="index", ylab="estimated a", pch=1, cex=0.7)
points(result.scia$res.opta, pch=2, cex=0.3, col="red")
plot(tb[,1], xlab="index", ylab="estimated b", pch=1, cex=0.7)
points(result.scia$res.optb, pch=2, cex=0.3, col="red")

## ----fig.width=10, fig.height=4------------------------------------------
result.scia.cv <- sCIA.cv(nX, nY, D, Qx, Qy, K=2, nfold=5, ngrid=10, flag=FALSE)
par(mfrow=c(1,2))
plot(ta[,1], xlab="index", ylab="estimated a", pch=1, cex=0.7)
points(result.scia.cv$resa[,1], pch=2, cex=0.3, col="red")
plot(tb[,1], xlab="index", ylab="estimated b", pch=1, cex=0.7)
points(result.scia.cv$resb[,1], pch=2, cex=0.3, col="red")

## ------------------------------------------------------------------------
netmats <- getNetMatrix(p, q, eX, eY, Qx, Qy)
tLx <- netmats$Sx # tilde{L}_x
tLy <- netmats$Sy # tilde{L}_y
result.sscia <- fitsscia(nX, nY, result.cia$res.opta[,1], result.cia$res.optb[,1], tLx, tLy, c(6, 1, 6, 0.5))

## ----fig.width=10, fig.height=4------------------------------------------
par(mfrow=c(1,2))
plot(ta[,1], xlab="index", ylab="estimated a", pch=1, cex=0.7)
points(result.sscia$res.opta, pch=2, cex=0.3, col="red")
plot(tb[,1], xlab="index", ylab="estimated b", pch=1, cex=0.7)
points(result.sscia$res.optb, pch=2, cex=0.3, col="red")

## ----fig.width=10, fig.height=4------------------------------------------
result.sscia.cv <- ssCIA.cv(nX, nY, D, Qx, Qy, tLx, tLy, K=2, nfold=5, ngrid=c(5, 5, 5 ,5), flag=FALSE)
par(mfrow=c(1,2))
plot(ta[,1], xlab="index", ylab="estimated a", pch=1, cex=0.7)
points(result.sscia.cv$res.opta[,1], pch=2, cex=0.3, col="red")
plot(tb[,1], xlab="index", ylab="estimated b", pch=1, cex=0.7)
points(result.sscia.cv$res.optb[,1], pch=2, cex=0.3, col="red")

## ------------------------------------------------------------------------
rm(list=ls())
library(pCIA)
data(list="NCI60", package="made4")
X <- t(NCI60$Ross)
Y <- t(NCI60$Affy)

## ------------------------------------------------------------------------
D <- diag(dim(X)[1])
Qx <- diag(apply(abs(X), 2, sum) / sum(abs(X)))
Qy <- diag(apply(abs(Y), 2, sum) / sum(abs(Y)))
nX <- sweep(X, 2, apply(X, 2, mean))
nY <- sweep(Y, 2, apply(Y, 2, mean))
result.cia <- oCIA(nX, nY, D, Qx, Qy) # this conduct classic CIA

## ----fig.width=10, fig.height=10-----------------------------------------
pinput <- genpInput(result.cia, NCI60$Annot[,2], NCI60$Annot[,4], NCI60$classes[,1], NCI60$classes[,2], nX, nY, D, Qx, Qy)
plot(pinput, nlab=5, labels = NULL)

## ------------------------------------------------------------------------
result.scia <- fitscia(nX, nY, result.cia$res.opta[,1], result.cia$res.optb[,1], c(6, 6))

## ----fig.width=10, fig.height=4------------------------------------------
par(mfrow=c(1,2))
plot(result.scia$res.opta, xlab="index", ylab="estimated a", pch=1, cex=0.7)
plot(result.scia$res.optb, xlab="index", ylab="estimated b", pch=1, cex=0.7)


## ----fig.width=10, fig.height=4------------------------------------------
result.scia.cv = sCIA.cv(nX, nY, D, Qx, Qy, K=2, nfold=5, ngrid=10, flag=FALSE)
par(mfrow=c(1,2))
plot(result.scia.cv$res.opta[,1], xlab="index", ylab="estimated a", pch=1, cex=0.7)
plot(result.scia.cv$res.optb[,1], xlab="index", ylab="estimated b", pch=1, cex=0.7)

## ----fig.width=10, fig.height=10-----------------------------------------
pinput = genpInput(result.scia.cv, NCI60$Annot[,2], NCI60$Annot[,4], NCI60$classes[,1], NCI60$classes[,2], nX, nY, D, Qx, Qy)
plot(pinput)

## ------------------------------------------------------------------------
data(NCI60path)
netmats <- getNetMatrix(dim(nX)[2], dim(nY)[2], NCI60path, NCI60path, Qx, Qy)
tLx <- netmats$Sx # tilde{L}_x
tLy <- netmats$Sy # tilde{L}_y
result.sscia <- fitsscia(nX, nY, result.cia$res.opta[,1], result.cia$res.optb[,1], tLx, tLy, c(6, 1, 6, 0.5))

## ----fig.width=10, fig.height=4------------------------------------------
par(mfrow=c(1,2))
plot(result.sscia$res.opta, xlab="index", ylab="estimated a", pch=1, cex=0.7)
plot(result.sscia$res.optb, xlab="index", ylab="estimated b", pch=1, cex=0.7)

## ----fig.width=10, fig.height=4------------------------------------------
result.sscia.cv <- ssCIA.cv(nX, nY, D, Qx, Qy, tLx, tLy, K=2, nfold=5, ngrid=c(5, 5, 5 ,5), flag=FALSE)
par(mfrow=c(1,2))
plot(result.sscia.cv$res.opta[,1], xlab="index", ylab="estimated a", pch=1, cex=0.7)
plot(result.sscia.cv$res.optb[,1], xlab="index", ylab="estimated b", pch=1, cex=0.7)

## ----fig.width=10, fig.height=10-----------------------------------------
pinput <- genpInput(result.sscia.cv, NCI60$Annot[,2], NCI60$Annot[,4], NCI60$classes[,1], NCI60$classes[,2], nX, nY, D, Qx, Qy)
plot(pinput)

