% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fitsscia.R
\name{fitsscia}
\alias{fitsscia}
\title{Structured Sparse Co-Inercia Analysis}
\usage{
fitsscia(X, Y, na, nb, Sx, Sy, lambdas, maxiter = 100)
}
\arguments{
\item{X}{n-by-p transformed data matrix of \code{X}, samples are rows and columns are features.}

\item{Y}{n-by-q transformeddata matrix of \code{Y}, samples are rows and columns are features.}

\item{na}{p-by-1 vector, initial values of loading vector of variables in \code{X}.}

\item{nb}{q-by-1 vector, initial values of loading vector of variables in \code{Y}.}

\item{Sx}{\eqn{Qx^{-1/2} E_x \Gamma_x^{1/2}} where \eqn{E_x} and \eqn{\Gamma_x^{1/2}} are
eigen vectors and eigen values of the Laplacian matrix of \code{X}. This is the output of \code{getNetMatrix}.}

\item{Sy}{\eqn{Qy^{-1/2} E_y \Gamma_y^{1/2}} where \eqn{E_y} and \eqn{\Gamma_y^{1/2}} are
eigen vectors and eigen values of the Laplacian matrix of \code{Y}. This is the output of \code{getNetMatrix}.}

\item{lambdas}{4-by-1 vector, the first and third values are sparsity penalty parameter for
variables in \code{X} and \code{Y} each and the second and fourth values are network
penalty parameters for variables in \code{X} and \code{Y} each.}
}
\value{
This function returns a list object.
\item{call}{the matched call.}
\item{res.opta}{the estimated loading vector of of transformated matrix of \code{X}.}
\item{res.optb}{the estimated loading vector of of transformated matrix of \code{Y}.}
}
\description{
This function conduct structured sparse CIA for a given tuning parameter value.
}
\examples{
data("demoData"); attach(demoData)
X <- setX[1:n,]; nX <- sweep(X, 2, apply(X, 2, mean))
Y <- setY[1:n,]; nY <- sweep(Y, 2, apply(Y, 2, mean))
result.cia <- oCIA(nX, nY, D, Qx, Qy)
netmats <- getNetMatrix(p, q, eX, eY, Qx, Qy)
tLx <- netmats$Sx # tilde{L}_x
tLy <- netmats$Sy # tilde{L}_y
result.sscia <- fitsscia(nX, nY, result.cia$res.opta[,1], result.cia$res.optb[,1], tLx, tLy, c(6, 1, 6, 0.5))
}
\seealso{
see also \code{\link{oCIA}}, \code{\link{getNetMatrix}}, \code{\link{ssCIA.cv}}.
}
