% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getNetMatrix.R
\name{getNetMatrix}
\alias{getNetMatrix}
\title{Generating Laplacian Matrix and its Eigendecompistion Results}
\usage{
getNetMatrix(p, q, eX, eY, Qx, Qy)
}
\arguments{
\item{p}{number of variables in the data \code{X}.}

\item{q}{number of variables in the data \code{Y}.}

\item{eX}{matrix that has two columns. Each rows contains location of variabes
that are connected to each other in the data \code{X}.}

\item{eY}{matrix that has two columns. Each rows contains location of variabes
that are connected to each other in the data \code{Y}.}

\item{Qx}{p-by-p diagonal weight matrix for variables of \code{X}.}

\item{Qy}{q-by-q diagonal weight matrix for variables of \code{Y}.}
}
\value{
This function returns a list object.

\item{Sx}{\eqn{Qx^{-1/2} E_x \Gamma_x^{1/2}} where \eqn{E_x} and \eqn{\Gamma_x^{1/2}} are
eigen vectors and eigen values of the Laplacian matrix of \code{X}. This is the output of \code{getNetMatrix}.}
\item{Sy}{\eqn{Qy^{-1/2} E_y \Gamma_y^{1/2}} where \eqn{E_y} and \eqn{\Gamma_y^{1/2}} are
eigen vectors and eigen values of the Laplacian matrix of \code{Y}. This is the output of \code{getNetMatrix}.}
}
\description{
This function calculate Laplacian matrix and computes the Eigendecompistion of the Laplacian matrix to
generate input matrix used in the ssCIA.
}
\examples{
data(list="NCI60", package="made4")
X <- t(NCI60$Ross); Y <- t(NCI60$Affy)
Qx <- diag(apply(abs(X), 2, sum) / sum(abs(X)))
Qy <- diag(apply(abs(Y), 2, sum) / sum(abs(Y)))
nX <- sweep(X, 2, apply(X, 2, mean))
nY <- sweep(Y, 2, apply(Y, 2, mean))
data(NCI60path)
netmats <- getNetMatrix(dim(nX)[2], dim(nY)[2], NCI60path, NCI60path, Qx, Qy)
}
