% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sCIA.cv.R
\name{sCIA.cv}
\alias{sCIA.cv}
\title{Sparse Co-Inercia Analysis  with Cross Validation for Chosing Optimal Tuning Parameters}
\usage{
sCIA.cv(X, Y, D, Qx, Qy, K = 1, TRUEval = NULL, nfold = 5, ngrid = 10,
  lambdarange = NULL, flag = TRUE)
}
\arguments{
\item{X}{n-by-p data matrix, samples are rows and columns are features.}

\item{Y}{n-by-q data matrix, samples are rows and columns are features.}

\item{D}{n-by-n diagonal weight matrix for samples.}

\item{Qx}{p-by-p diagonal weight matrix for variables of X.}

\item{Qy}{q-by-q diagonal weight matrix for variables of Y.}

\item{K}{number of loading pairs to be estimated.}

\item{TRUEval}{a list containing true loading vectors of \code{X} and \code{Y} in the simulation.}

\item{nfold}{number of subgroups that data is separated into for cross validation procedure.}

\item{ngrid}{number of possible tuning paramter values that will be searched.}

\item{lambdarange}{a vector contains four numbers. First and the second values are the minimum
and maximum value of ranges for tuniing parameters for \code{X}, the third and fourth are the
minimum and maximum value of ranges for tuniing parameters for \code{Y}.}
}
\value{
This function returns a list object. If this is used for a simulation and
\code{TRUEval} is used, the output list contains \code{CVobjs}, \code{OptTaus},
and \code{resa}, \code{resb}, \code{res.mea}, \code{res.num}. If \code{TRUEval} is set as default,
\code{NULL}, then the output list contains \code{Cvobjs}, \code{OptTaus},
and \code{resa}, and \code{resb}.
\item{call}{the matched call.}
\item{CVobjs}{cross validation objective values for all combination of tuning parameters.}
\item{OptTaus}{the chosen optimal tuning parameter pairs.}
\item{res.opta}{estimated loading vectors of of the transformated matrix \eqn{D^{1/2} X Qx^{1/2}}.}
\item{res.optb}{estimated loading vectors of of the transformated matrix \eqn{D^{1/2} Y Qy^{1/2}}.}
\item{res.mea}{feature selction performance measures, sensitivity, specificity, MCC, and angle.}
\item{res.num}{count values, true positives, true negatives, false positives, and false negatives.}
}
\description{
This function can be used to automatically select tuning parameters for sparse CIA.
}
\examples{
data("demoData"); attach(demoData)
X <- setX[1:n,]; nX <- sweep(X, 2, apply(X, 2, mean))
Y <- setY[1:n,]; nY <- sweep(Y, 2, apply(Y, 2, mean))
result.scia.cv <- sCIA.cv(nX, nY, D, Qx, Qy, K=2, nfold=5, ngrid=10, flag=FALSE)
}
\seealso{
see also \code{\link{fitscia}}.
}
