% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ssCIA.cv.R
\name{ssCIA.cv}
\alias{ssCIA.cv}
\title{Structured Sparse Co-Inercia Analysis  with Cross Validation for Chosing Optimal Tuning Parameters}
\usage{
ssCIA.cv(X, Y, D, Qx, Qy, Sx, Sy, K = 1, nfold = 5, TRUEval = NULL,
  ngrid = c(10, 3, 10, 3), lambdarange = NULL, lambda2range = NULL,
  flag = TRUE)
}
\arguments{
\item{X}{n-by-p data matrix, samples are rows and columns are features.}

\item{Y}{n-by-q data matrix, samples are rows and columns are features.}

\item{D}{n-by-n diagonal weight matrix for samples.}

\item{Qx}{p-by-p diagonal weight matrix for variables of \code{X}.}

\item{Qy}{q-by-q diagonal weight matrix for variables of \code{Y}.}

\item{Sx}{\eqn{Qx^{-1/2} E_x \Gamma_x^{1/2}} where \eqn{E_x} and \eqn{\Gamma_x^{1/2}} are
eigen vectors and eigen values of the Laplacian matrix of \code{X}. This is the output of \code{getNetMatrix}.}

\item{Sy}{\eqn{Qy^{-1/2} E_y \Gamma_y^{1/2}} where \eqn{E_y} and \eqn{\Gamma_y^{1/2}} are
eigen vectors and eigen values of the Laplacian matrix of \code{Y}. This is the output of \code{getNetMatrix}.}

\item{K}{number of loading pairs to be estimated.}

\item{nfold}{number of subgroups that data is separated into for cross validation procedure.}

\item{TRUEval}{a list containing true loading vectors of \code{X} and \code{Y} in the simulation.}

\item{ngrid}{number of possible tuning paramter values that will be searched.}

\item{lambdarange}{a vector contains four numbers he range of sparsity penalty parameters.
\code{genGridPT} function calculates grid points based on this ranage. Default values are \code{NULL},
in this case \code{genGridPT} function calculate range of tuning parameters from the result of lasso regression of glm package.
Users can set the range of tuning parameters by putting desirable values. First and the second values
are the minimum and maximum value of ranges for tuning parameters for \code{X}, the third and fourth area
the minimum and maximum value of ranges for tuning parameters for \code{Y}.}

\item{lambda2range}{a vector contains four numbers the range of network penalty parameters.
\code{genGridPT} function calculates grid points based on this ranage. Default values are \code{NULL},
in this case \code{genGridPT} function use three values (0.1, 0.5, 1) as a grid point.
Users can set the range of tuning parameters by putting desirable values. First and the second values
are the minimum and maximum value of ranges for tuning parameters for \code{X}, the third and fourth area
the minimum and maximum value of ranges for tuning parameters for \code{Y}.}
}
\value{
This function returns a list object. If this is used for a simulation and
\code{TRUEval} is used, the output list contains \code{CVobjs}, \code{OptTaus},
and \code{resa}, \code{resb}, \code{res.mea}, \code{res.num}. If \code{TRUEval} is set as default,
\code{NULL}, then the output list contains \code{Cvobjs}, \code{OptTaus},
and \code{resa}, and \code{resb}.
\item{call}{the matched call.}
\item{CVobjs}{cross validation objective values for all combination of tuning parameters.}
\item{OptTaus}{the chosen optimal tuning parameter pairs.}
\item{resa}{estimated loading vectors of of the transformated matrix \eqn{D^{1/2} X Qx^{1/2}}.}
\item{resb}{estimated loading vectors of of the transformated matrix \eqn{D^{1/2} Y Qy^{1/2}}.}
\item{res.mea}{feature selction performance measures, sensitivity, specificity, MCC, and angle.}
\item{res.num}{count values, true positives, true negatives, false positives, and false negatives.}
}
\description{
This function can be used to automatically select tuning parameters for structured sparse CIA.
}
\examples{
data("demoData"); attach(demoData)
X <- setX[1:n,]; nX <- sweep(X, 2, apply(X, 2, mean))
Y <- setY[1:n,]; nY <- sweep(Y, 2, apply(Y, 2, mean))
netmats <- getNetMatrix(p, q, eX, eY, Qx, Qy)
tLx <- netmats$Sx # tilde{L}_x
tLy <- netmats$Sy # tilde{L}_y
result.sscia.cv <- ssCIA.cv(nX, nY, D, Qx, Qy, tLx, tLy, K=2, nfold=5, ngrid=c(5, 5, 5 ,5), flag=FALSE)
}
\seealso{
see also \code{\link{oCIA}}, \code{\link{getNetMatrix}}, \code{\link{fitsscia}}.
}
